# Calculator Package

## Technologies

* [Python 3.9](https://python.org) : Base programming language for development. The latest version of python.
* [Docker Engine and Docker Compose](https://www.docker.com/) : Containerization of the application and services orchestration

## Description
This package just implements a simple Calculator that can do basic addition, subtraction, multiplication, division and nth root calculation.
Like most other calculators, this calculator can be reset and cleared of all previous calculation history with the reset method.

## Getting Started

Using this package is very simple, all you need is to have Git and Docker Engine installed on your machine. 
cd into your project, then open up your terminal and run this command `pip install git+https://github.com/Rafiatu/calculator` to install the package and you're good to go!

## Testing

This package has pytest embedded in it and can be run with the following command `python -m pytest tests/`


## License

The MIT License - Copyright (c) 2021 - Rafihatu Bello
